@@ -575,12 +575,12 @@ class S3UtilsTest(unittest.TestCase):
             local_root = os.path.join(resources_directory, "unittest", "s3utils")
             local_members = [os.path.relpath(file_path, local_root) for file_path in listfile(local_root)]
 
-            for archive_key, members, mode, threshold, use_chunked_reads in itertools.product(
+            for archive_key, members, mode, use_ranged_requests, use_chunked_reads in itertools.product(
                 ["s3utils_archive/archive.uncompressed.zip", "s3utils_archive/archive.compressed.zip"],
                 [local_members, None],
                 ["r", "rb"],
-                [1.0, 0.0],
-                [False, True],
+                [False, True, s3_archive_use_ranged_requests()],
+                [False, True, s3_archive_use_chunked_reads()],
             ):
                 for member, opener in s3_archive_open_members(
                     client,
@@ -588,8 +588,7 @@ class S3UtilsTest(unittest.TestCase):
                     archive_key,
                     members,
                     mode,
-                    threshold=threshold,
-                    central_directory_overhead=0,
+                    use_ranged_requests=use_ranged_requests,
                     use_chunked_reads=use_chunked_reads,
                 ):
                     with open(os.path.join(local_root, member), mode) as local_fh, opener() as s3_fh:
